==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/authorization/kotlin/inputs/PermissionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.authorization.kotlin.inputs

import com.pulumi.azurenative.authorization.inputs.PermissionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Role definition permissions.
 * @property actions Allowed actions.
 * @property dataActions Allowed Data actions.
 * @property notActions Denied actions.
 * @property notDataActions Denied Data actions.
 */
public data class PermissionArgs(
    public val actions: Output<List<String>>? = null,
    public val dataActions: Output<List<String>>? = null,
    public val notActions: Output<List<String>>? = null,
    public val notDataActions: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.authorization.inputs.PermissionArgs> {
    override fun toJava(): com.pulumi.azurenative.authorization.inputs.PermissionArgs =
        com.pulumi.azurenative.authorization.inputs.PermissionArgs.builder()
            .actions(actions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .dataActions(dataActions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notActions(notActions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notDataActions(notDataActions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PermissionArgs].
 */
@PulumiTagMarker
public class PermissionArgsBuilder internal constructor() {
    private var actions: Output<List<String>>? = null

    private var dataActions: Output<List<String>>? = null

    private var notActions: Output<List<String>>? = null

    private var notDataActions: Output<List<String>>? = null

    /**
     * @param value Allowed actions.
     */
    @JvmName("wvawpbhhpdpxetqt")
    public suspend fun actions(`value`: Output<List<String>>) {
        this.actions = value
    }

    @JvmName("hnxownqqawcimyhq")
    public suspend fun actions(vararg values: Output<String>) {
        this.actions = Output.all(values.asList())
    }

    /**
     * @param values Allowed actions.
     */
    @JvmName("xifhubghewxmvwgr")
    public suspend fun actions(values: List<Output<String>>) {
        this.actions = Output.all(values)
    }

    /**
     * @param value Allowed Data actions.
     */
    @JvmName("jiruajetrmwtwbsb")
    public suspend fun dataActions(`value`: Output<List<String>>) {
        this.dataActions = value
    }

    @JvmName("rmnliuvnfnqevrrq")
    public suspend fun dataActions(vararg values: Output<String>) {
        this.dataActions = Output.all(values.asList())
    }

    /**
     * @param values Allowed Data actions.
     */
    @JvmName("qadnocxkgvvdskpf")
    public suspend fun dataActions(values: List<Output<String>>) {
        this.dataActions = Output.all(values)
    }

    /**
     * @param value Denied actions.
     */
    @JvmName("aegeuqjrsviwkqwp")
    public suspend fun notActions(`value`: Output<List<String>>) {
        this.notActions = value
    }

    @JvmName("fevgfghutjpjfsor")
    public suspend fun notActions(vararg values: Output<String>) {
        this.notActions = Output.all(values.asList())
    }

    /**
     * @param values Denied actions.
     */
    @JvmName("vhiasjhosjtxnhqw")
    public suspend fun notActions(values: List<Output<String>>) {
        this.notActions = Output.all(values)
    }

    /**
     * @param value Denied Data actions.
     */
    @JvmName("vaxpapmgrhbynuds")
    public suspend fun notDataActions(`value`: Output<List<String>>) {
        this.notDataActions = value
    }

    @JvmName("npmsiumrwvouqmxy")
    public suspend fun notDataActions(vararg values: Output<String>) {
        this.notDataActions = Output.all(values.asList())
    }

    /**
     * @param values Denied Data actions.
     */
    @JvmName("aabalyqttoulnatw")
    public suspend fun notDataActions(values: List<Output<String>>) {
        this.notDataActions = Output.all(values)
    }

    /**
     * @param value Allowed actions.
     */
    @JvmName("foiessmnpwdnojxd")
    public suspend fun actions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param values Allowed actions.
     */
    @JvmName("gymjcjurcuqmvjtd")
    public suspend fun actions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param value Allowed Data actions.
     */
    @JvmName("jbkmkbmhrttaepwk")
    public suspend fun dataActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataActions = mapped
    }

    /**
     * @param values Allowed Data actions.
     */
    @JvmName("eolaamkmnddiftqu")
    public suspend fun dataActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataActions = mapped
    }

    /**
     * @param value Denied actions.
     */
    @JvmName("mgywbnjudicgdasc")
    public suspend fun notActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notActions = mapped
    }

    /**
     * @param values Denied actions.
     */
    @JvmName("gvbgddntwmjbcpjh")
    public suspend fun notActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notActions = mapped
    }

    /**
     * @param value Denied Data actions.
     */
    @JvmName("gfwjhhtubikttlqd")
    public suspend fun notDataActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notDataActions = mapped
    }

    /**
     * @param values Denied Data actions.
     */
    @JvmName("nhdutwtjomfaiqou")
    public suspend fun notDataActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notDataActions = mapped
    }

    internal fun build(): PermissionArgs = PermissionArgs(
        actions = actions,
        dataActions = dataActions,
        notActions = notActions,
        notDataActions = notDataActions,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/authorization/kotlin/inputs/PermissionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.authorization.kotlin.inputs

import com.pulumi.azurenative.authorization.inputs.PermissionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Role definition permissions.
 * @property actions Allowed actions.
 * @property dataActions Allowed Data actions.
 * @property notActions Denied actions.
 * @property notDataActions Denied Data actions.
 */
public data class PermissionArgs(
    public val actions: Output<List<String>>? = null,
    public val dataActions: Output<List<String>>? = null,
    public val notActions: Output<List<String>>? = null,
    public val notDataActions: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.authorization.inputs.PermissionArgs> {
    override fun toJava(): com.pulumi.azurenative.authorization.inputs.PermissionArgs =
        com.pulumi.azurenative.authorization.inputs.PermissionArgs.builder()
            .actions(actions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .dataActions(dataActions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notActions(notActions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notDataActions(notDataActions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PermissionArgs].
 */
@PulumiTagMarker
public class PermissionArgsBuilder internal constructor() {
    private var actions: Output<List<String>>? = null

    private var dataActions: Output<List<String>>? = null

    private var notActions: Output<List<String>>? = null

    private var notDataActions: Output<List<String>>? = null

    /**
     * @param value Allowed actions.
     */
    @JvmName("bchqeiwjqvhgxywt")
    public suspend fun actions(`value`: Output<List<String>>) {
        this.actions = value
    }

    @JvmName("mvckrxsshmpgtqmt")
    public suspend fun actions(vararg values: Output<String>) {
        this.actions = Output.all(values.asList())
    }

    /**
     * @param values Allowed actions.
     */
    @JvmName("nppjworphbpojesd")
    public suspend fun actions(values: List<Output<String>>) {
        this.actions = Output.all(values)
    }

    /**
     * @param value Allowed Data actions.
     */
    @JvmName("ooskwfvdphvcpark")
    public suspend fun dataActions(`value`: Output<List<String>>) {
        this.dataActions = value
    }

    @JvmName("iahgryifklltbcyf")
    public suspend fun dataActions(vararg values: Output<String>) {
        this.dataActions = Output.all(values.asList())
    }

    /**
     * @param values Allowed Data actions.
     */
    @JvmName("pcwmnothvtrnvclm")
    public suspend fun dataActions(values: List<Output<String>>) {
        this.dataActions = Output.all(values)
    }

    /**
     * @param value Denied actions.
     */
    @JvmName("rpqhckbvugseqyuj")
    public suspend fun notActions(`value`: Output<List<String>>) {
        this.notActions = value
    }

    @JvmName("dysbnpvtnknhgbxl")
    public suspend fun notActions(vararg values: Output<String>) {
        this.notActions = Output.all(values.asList())
    }

    /**
     * @param values Denied actions.
     */
    @JvmName("lmatvccsnllhcapu")
    public suspend fun notActions(values: List<Output<String>>) {
        this.notActions = Output.all(values)
    }

    /**
     * @param value Denied Data actions.
     */
    @JvmName("fxynanlcsvnybmtk")
    public suspend fun notDataActions(`value`: Output<List<String>>) {
        this.notDataActions = value
    }

    @JvmName("cusaxrtdupadggup")
    public suspend fun notDataActions(vararg values: Output<String>) {
        this.notDataActions = Output.all(values.asList())
    }

    /**
     * @param values Denied Data actions.
     */
    @JvmName("rakellnhoqwnkmau")
    public suspend fun notDataActions(values: List<Output<String>>) {
        this.notDataActions = Output.all(values)
    }

    /**
     * @param value Allowed actions.
     */
    @JvmName("qgrmxcsvfglgikkh")
    public suspend fun actions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param values Allowed actions.
     */
    @JvmName("dkwosntfpphrvhmf")
    public suspend fun actions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param value Allowed Data actions.
     */
    @JvmName("bdnkhablbshmjitr")
    public suspend fun dataActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataActions = mapped
    }

    /**
     * @param values Allowed Data actions.
     */
    @JvmName("sehcsrxugewagjua")
    public suspend fun dataActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataActions = mapped
    }

    /**
     * @param value Denied actions.
     */
    @JvmName("vfkwpkkafqougymc")
    public suspend fun notActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notActions = mapped
    }

    /**
     * @param values Denied actions.
     */
    @JvmName("bixmsciwikrqloyq")
    public suspend fun notActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notActions = mapped
    }

    /**
     * @param value Denied Data actions.
     */
    @JvmName("xkwvciefmetfdmmj")
    public suspend fun notDataActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notDataActions = mapped
    }

    /**
     * @param values Denied Data actions.
     */
    @JvmName("lmuodbwehpbaxxsl")
    public suspend fun notDataActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notDataActions = mapped
    }

    internal fun build(): PermissionArgs = PermissionArgs(
        actions = actions,
        dataActions = dataActions,
        notActions = notActions,
        notDataActions = notDataActions,
    )
}
